@@ -1,14 +1,17 @@
 """
 Scrapy - a screen scraping framework written in Python
 """
+from __future__ import print_function
 import pkgutil
 __version__ = pkgutil.get_data(__package__, 'VERSION').strip()
+if not isinstance(__version__, str):
+    __version__ = __version__.decode('ascii')
 version_info = tuple(__version__.split('.')[:3])
 
 import sys, os, warnings
 
-if sys.version_info < (2,6):
-    print "Scrapy %s requires Python 2.6 or above" % __version__
+if sys.version_info < (2, 7):
+    print("Scrapy %s requires Python 2.7" % __version__)
     sys.exit(1)
 
 # ignore noisy twisted deprecation warnings
@@ -30,13 +33,6 @@ except ImportError:
 else:
     optional_features.add('boto')
 
-try:
-    import libxml2
-except ImportError:
-    pass
-else:
-    optional_features.add('libxml2')
-
 try:
     import django
 except ImportError:
