@@ -1,3 +1,4 @@
+from __future__ import print_function
 import sys
 import string
 import re
@@ -36,11 +37,11 @@ class Command(ScrapyCommand):
             raise UsageError()
         project_name = args[0]
         if not re.search(r'^[_a-zA-Z]\w*$', project_name):
-            print 'Error: Project names must begin with a letter and contain only\n' \
-                'letters, numbers and underscores'
+            print('Error: Project names must begin with a letter and contain only\n' \
+                'letters, numbers and underscores')
             sys.exit(1)
         elif exists(project_name):
-            print "Error: directory %r already exists" % project_name
+            print("Error: directory %r already exists" % project_name)
             sys.exit(1)
 
         moduletpl = join(TEMPLATES_PATH, 'module')
