@@ -37,7 +37,7 @@ class BaseSgmlLinkExtractor(FixedSGMLParser):
                 link.url = link.url.encode(response_encoding)
             link.url = urljoin(base_url, link.url)
             link.url = safe_url_string(link.url, response_encoding)
-            link.text = str_to_unicode(link.text, response_encoding, errors='replace')
+            link.text = str_to_unicode(link.text, response_encoding, errors='replace').strip()
             ret.append(link)
 
         return ret
@@ -74,11 +74,12 @@ class BaseSgmlLinkExtractor(FixedSGMLParser):
                         self.current_link = link
 
     def unknown_endtag(self, tag):
-        self.current_link = None
+        if self.scan_tag(tag):
+            self.current_link = None
 
     def handle_data(self, data):
         if self.current_link:
-            self.current_link.text = self.current_link.text + data.strip()
+            self.current_link.text = self.current_link.text + data
 
     def matches(self, url):
         """This extractor matches with any url, since
@@ -121,7 +122,7 @@ class SgmlLinkExtractor(BaseSgmlLinkExtractor):
             body = u''.join(f
                             for x in self.restrict_xpaths
                             for f in sel.xpath(x).extract()
-                            ).encode(response.encoding)
+                            ).encode(response.encoding, errors='xmlcharrefreplace')
         else:
             body = response.body
 
