@@ -16,6 +16,14 @@ class HttpError(IgnoreRequest):
 
 class HttpErrorMiddleware(object):
 
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls(crawler.settings)
+
+    def __init__(self, settings):
+        self.handle_httpstatus_all = settings.getbool('HTTPERROR_ALLOW_ALL')
+        self.handle_httpstatus_list = settings.getlist('HTTPERROR_ALLOWED_CODES')
+
     def process_spider_input(self, response, spider):
         if 200 <= response.status < 300: # common case
             return
@@ -24,8 +32,10 @@ class HttpErrorMiddleware(object):
             return
         if 'handle_httpstatus_list' in meta:
             allowed_statuses = meta['handle_httpstatus_list']
+        elif self.handle_httpstatus_all:
+            return
         else:
-            allowed_statuses = getattr(spider, 'handle_httpstatus_list', ())
+            allowed_statuses = getattr(spider, 'handle_httpstatus_list', self.handle_httpstatus_list)
         if response.status in allowed_statuses:
             return
         raise HttpError(response, 'Ignoring non-200 response')
