@@ -123,6 +123,7 @@ class SgmlLinkExtractorTestCase(unittest.TestCase):
             Link(url='http://example.com/sample2.html', text=u'sample 2'),
             Link(url='http://example.com/sample3.html', text=u'sample 3 text'),
             Link(url='http://www.google.com/something', text=u''),
+            Link(url='http://example.com/innertag.html', text=u'inner tag'),
         ])
 
         lx = SgmlLinkExtractor(allow=('sample', ))
@@ -236,6 +237,13 @@ class SgmlLinkExtractorTestCase(unittest.TestCase):
         self.assertEqual(lx.extract_links(response),
                          [Link(url='http://example.org/about.html', text=u'About us\xa3')])
 
+    def test_restrict_xpaths_with_html_entities(self):
+        html = '<html><body><p><a href="/&hearts;/you?c=&euro;">text</a></p></body></html>'
+        response = HtmlResponse("http://example.org/somepage/index.html", body=html, encoding='iso8859-15')
+        links = SgmlLinkExtractor(restrict_xpaths='//p').extract_links(response)
+        self.assertEqual(links,
+                         [Link(url='http://example.org/%E2%99%A5/you?c=%E2%82%AC', text=u'text')])
+
     def test_restrict_xpaths_concat_in_handle_data(self):
         """html entities cause SGMLParser to call handle_data hook twice"""
         body = """<html><body><div><a href="/foo">&gt;\xbe\xa9&lt;\xb6\xab</a></body></html>"""
@@ -305,12 +313,12 @@ class HtmlParserLinkExtractorTestCase(unittest.TestCase):
     def test_extraction(self):
         # Default arguments
         lx = HtmlParserLinkExtractor()
-        self.assertEqual([link for link in lx.extract_links(self.response)], [
-            Link(url='http://example.com/sample2.html', text=u'sample 2'),
-            Link(url='http://example.com/sample3.html', text=u'sample 3 text'),
-            Link(url='http://example.com/sample3.html', text='sample 3 repetition'),
-            Link(url='http://www.google.com/something', text=''),
-        ])
+        self.assertEqual(lx.extract_links(self.response),
+                         [Link(url='http://example.com/sample2.html', text=u'sample 2'),
+                          Link(url='http://example.com/sample3.html', text=u'sample 3 text'),
+                          Link(url='http://example.com/sample3.html', text=u'sample 3 repetition'),
+                          Link(url='http://www.google.com/something', text=u''),
+                          Link(url='http://example.com/innertag.html', text=u'inner tag'),])
 
 
 class RegexLinkExtractorTestCase(unittest.TestCase):
@@ -322,13 +330,11 @@ class RegexLinkExtractorTestCase(unittest.TestCase):
     def test_extraction(self):
         # Default arguments
         lx = RegexLinkExtractor()
-        # Note that RegexLinkExtractor returns links in arbitrary order,
-        # so we need to sort them for comparison
-        self.assertEqual(sorted(lx.extract_links(self.response), key=lambda x: x.url), [
-            Link(url='http://example.com/sample2.html', text=u'sample 2'),
-            Link(url='http://example.com/sample3.html', text=u'sample 3 repetition'),
-            Link(url='http://www.google.com/something', text=u''),
-        ])
+        self.assertEqual(lx.extract_links(self.response),
+                         [Link(url='http://example.com/sample2.html', text=u'sample 2'),
+                          Link(url='http://example.com/sample3.html', text=u'sample 3 text'),
+                          Link(url='http://www.google.com/something', text=u''),
+                          Link(url='http://example.com/innertag.html', text=u'inner tag'),])
 
 
 if __name__ == "__main__":
